package com.use.cloud.mall.floor.api;

import com.use.cloud.mall.floor.domain.Floor;
import com.use.cloud.mall.floor.domain.Item;
import com.use.cloud.mall.floor.service.FloorService;
import java.net.URI;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.util.UriComponentsBuilder;

/**
 * 楼层API
 *
 * @author yangck
 */
@RestController
@RequestMapping("/floors")
public class FloorController {

    private final FloorService floorService;

    @Autowired
    public FloorController(FloorService floorService) {
        this.floorService = floorService;
    }

    // 获取某一模块的楼层
    @GetMapping(produces = "application/json")
    public List<Floor> floors(@RequestParam("usedFor") String usedFor) {
        return floorService.findByUsedFor(usedFor);
    }

    // 新增一个楼层
    @PostMapping(consumes = "application/json")
    @ResponseStatus(HttpStatus.CREATED)
    public ResponseEntity<Floor> save(@RequestBody Floor floor, UriComponentsBuilder ucb) {
        Floor saved = floorService.save(floor);

        HttpHeaders headers = new HttpHeaders();
        URI locationUri = ucb.path("/carousel")
                .path(String.valueOf(floor.getId()))
                .build()
                .toUri();
        headers.setLocation(locationUri);

        return new ResponseEntity<>(saved, headers, HttpStatus.CREATED);
    }

    /**
     * 修改或保存明细
     * @param id
     * @param item
     */
    @PostMapping(value = "/{id}/item" )
    public Floor updateItem(@PathVariable("id") String id, @RequestBody Item item) {
       return floorService.saveItem(id, item);
    }
    /**
     * 删除明细
     * @param id
     * @param itemid
     */
    @DeleteMapping(value = "/{id}/{itemid}" )
    public void deleteItem(@PathVariable("id") String id,  @PathVariable("itemid") Long itemid) {
        floorService.deleteItem(id, itemid);
    }

    @GetMapping(value = "/{id}", produces = "application/json")
    public Floor floor(@PathVariable String id) {
        return floorService.findOne(id);
    }

    @DeleteMapping(value = "/{id}")
    public void delete(@PathVariable String id) {
        floorService.delete(id);
    }
}
