package com.use.cloud.mall.floor.service.impl;

import com.use.cloud.mall.floor.domain.Floor;
import com.use.cloud.mall.floor.domain.Item;
import com.use.cloud.mall.floor.repository.FloorRepository;
import com.use.cloud.mall.floor.service.FloorService;
import java.util.ArrayList;
import java.util.List;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

/**
 * @author yangck
 * @create 2017-02-27 17:55
 */
@Service
public class FloorServiceImpl implements FloorService {

    public static final Logger logger = Logger.getLogger(FloorService.class);

    @Autowired
    private FloorRepository floorRepository;

    @Override
    public List<Floor> findByUsedFor(String usedFor) {
        return floorRepository.findByUsedForOrderByFloorNumberAsc(usedFor);
    }

    @Override
    public Floor findOne(String id) {
        return floorRepository.findOne(id);
    }

    @Override
    public Floor save(Floor floor) {
        return floorRepository.save(floor);
    }

    @Override
    public void delete(String id) {
        floorRepository.delete(id);
    }

    @Override
    public Floor saveItem(String id, Item item) {
        Floor floor = floorRepository.findOne(id);
        if (floor == null) {
            return null;
        }

        boolean update = false;
        if (!isFloorHaveNoItems(floor) && isExistingItem(item)) {
            for (Item exitItem : floor.getItems()) {
                if (!exitItem.getId().equals(item.getId())) {
                    continue;
                }

                update = true;

                logger.info(String.format("Item name: %s", item.getName()));
                exitItem.setName(item.getName());
                exitItem.setBody(item.getBody());
                exitItem.setHrefUrl(item.getHrefUrl());
                exitItem.setPictureUrl(item.getPictureUrl());
                exitItem.setOrderNumber(item.getOrderNumber());
                exitItem.setSize(item.getSize());
                exitItem.setBackGroundColor(item.getBackGroundColor());
            }
        }
        if (!update) {
            if (isFloorHaveNoItems(floor)) {
                floor.setItems(new ArrayList<Item>());
            }
            floor.getItems().add(item);
        }
        return floorRepository.save(floor);
    }

    @Override
    public void deleteItem(String id, Long itemid) {
        Floor floor = floorRepository.findOne(id);
        if (floor == null) {
            return;
        }

        if (!isFloorHaveNoItems(floor)) {
            for (Item exitItem : floor.getItems()) {
                if (exitItem.getId().equals(itemid)) {
                    floor.getItems().remove(exitItem);
                    break;
                }
            }
        }
        floorRepository.save(floor);
    }

    private static boolean isFloorHaveNoItems(Floor floor) {
        return CollectionUtils.isEmpty(floor.getItems());
    }

    private static boolean isExistingItem(Item item) {
        return !StringUtils.isEmpty(item.getId());
    }
}
